@@ -1,4 +1,4 @@
-/*** analog 2.0 ***/
+/*** analog 2.1 ***/
 /* Please read Readme.html, or http://www.statslab.cam.ac.uk/~sret1/analog/  */
 
 /*** alias.c; functions to cope with aliasing, etc. ***/
@@ -57,7 +57,7 @@ flag dnsresolve(char *hostn)
   if (addr != INET_ADDR_ERR) {
     addrp = (const char *) &addr;
     tempp = gethostbyaddr(addrp, sizeof(struct in_addr), AF_INET);
-    if (tempp != NULL) {
+    if (tempp != NULL && tempp -> h_name[0] != '\0') {
       if (debug >= 2)
 	fprintf(stderr, "D: %s -> %s\n", hostn, tempp -> h_name);
       strncpy(hostn, tempp -> h_name, MAXSTRINGLENGTH - 1);
@@ -173,7 +173,8 @@ int doaliasfile(char *filename)
   /* If contains ?, already done at sscanf time */
 
   if (case_insensitive && strrchr(filename, '?') == NULL)
-    anydone = strtolowerf(filename);
+    if(strtolowerf(filename))
+      anydone = ON;
 
   /* Thirdly, if it ends with the DIRSUFFIX (often index.html), strip it */
 
@@ -233,7 +234,7 @@ int doaliasfile(char *filename)
 
   /* Lastly, alias conversion from config. file */
 
-  if(doaliaslist(filename, filealiashead))
+  if (doaliaslist(filename, filealiashead))
     anydone = ON;
 
   return(anydone);
@@ -393,8 +394,8 @@ int doalias(char *name, char codeletter)
 /* Now a function to run through all hosts, files or refs doing all aliases */
 
 void allaliases(struct genstruct **objhead, struct genstruct **objhead2,
-		int hashsize, int *totalobjs, int *totalobjs7, int *totalnew7,
-		char code)
+		size_t hashsize, int *totalobjs, int *totalobjs7,
+		int *totalnew7, char code)
 {
   int onlist;
   struct genstruct *p, *nextp;
