@@ -1,10 +1,18 @@
-/* analform.c 2.0 -- parse the output of the analog form interface */
+/* analform.c 2.1 -- parse the output of the analog form interface */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 
+#ifdef _WIN32  /* so it can pick it up automatically */
+#undef WIN32
+#define WIN32
+#endif
+#ifdef WIN32
+#define popen _popen
+#define pclose _pclose
+#endif
 extern FILE *popen();  /* to stop gcc complaining */
 extern int pclose();
 extern int putenv();
