@@ -1,4 +1,4 @@
-/*** analhea2.h; header file for analog version 2.0 ***/
+/*** analhea2.h; header file for analog version 2.1 ***/
 /* Please read Readme.html, or http://www.statslab.cam.ac.uk/~sret1/analog/ */
 
 /*** These things are not intended to be user definable;
@@ -9,7 +9,7 @@
 
 /*** First some #define's and #include's. Start with system specific ones ***/
 
-#define VNUMBER "2.0"    /* the version number of this program */
+#define VNUMBER "2.11"    /* the version number of this program */
 
 #ifdef __MWERKS__
 #define MAC        /* So MWERKS compiler automatically switches to Mac */
@@ -49,9 +49,25 @@
 #define DIRSEP '/'
 #endif
 
+#ifdef _WIN32  /* so it can pick it up automatically */
+#undef WIN32
+#define WIN32
+#endif
 #ifdef WIN32
 #define VERSION VNUMBER "/Win32"
 #define DIRSEP '\\'
+#define popen _popen
+#define pclose _pclose
+extern void Win32Init(void);
+extern void Win32Cleanup(void);
+#endif
+
+#ifdef RISCOS
+#define NODNS
+#define NOPIPES
+#define NODIRENT
+#define VERSION VNUMBER "/RISCOS"
+#define DIRSEP '.'
 #endif
 
 /* If no OS is defined, the compilation will fail by not knowing VERSION */
@@ -84,6 +100,10 @@
 #include <OpenTptInternet.h>
 #include <AddressXlation.h>
 #else
+#ifdef WIN32
+#include <winsock.h>
+#define INET_ADDR_ERR INADDR_NONE
+#else
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <netdb.h>
@@ -91,6 +111,7 @@
 #define INET_ADDR_ERR (-1)   /* what inet_addr() returns on error */
 #endif
 #endif
+#endif
 #ifdef MAC_EVENTS
 #define MAC_IDLE_FREQ (200)
 #endif
@@ -213,6 +234,30 @@
 #define MAXERRLENGTH (40)  /* the longest one */
 #define NO_STATUS (22) /* how many status codes are defined */
 #define MAXSTATUSLENGTH (35)
+#define NOLNGSTRS (149) /* how many lngstr's */
+
+enum {weekbeg_, month_, day_, days_, hr_, minute_, minutes_, second_, seconds_,
+	byte_, bytes_, request_, requests_, date_, file_, host_, dir_, dom_,
+	ext_, url_, browser_, nr_, description_, webstatsfor_, monthrep_,
+	weekrep_, daysum_, dayrep_, hourrep_, hoursum_, hostrep_, hostgs_,
+	hostgp_, hostgen_, dirrep_, dirgs_, dirgp_, dirgen_, typerep_, extgs_,
+	extgp_, extgen_, reqrep_, filegs_, filegp_, filegen_, refrep_, refgs_,
+	refgp_, refgen_, browsum_, browgs_, browgp_, browgen_, browrep_,
+	domrep_, domgs_, domgp_, domgen_, subdomgs_, subdomgp_, subdomgen_,
+	credit_, runtime_, lessone_, dirlevel_, eachunit_, represents_,
+	partof_, pagereq_, pagereqs_, statrep_, errrep_, allerrs_, allerrs1_,
+	allerrsn_, occsort_, errtype_, progstart_, localtime_, reqstart_, to_,
+	succreqs_, avereqs_, totpages_, avepages_, totfails_, totredirs_,
+	distfiles_, disthosts_, approxhosts_, newhosts_, approxnewhosts_,
+	corrupt_, unwanted_, totdata_, avedata_, brackets_, sevendaysto_,
+	lastsevendays_, goto_, top_, nreqs_, preqs_, noccs_, poccs_, npgs_,
+	ppgs_, nbytes_, pbytes_, firstsm_, firstsf_, firstsn_, firstdsm_,
+	firstdsf_, firstdsn_, allsm_, allsf_, allsn_, atleast_, ptraffic_,
+	btraffic_, sortedms_, sortedfs_, sortedns_, sortedmp_, sortedfp_,
+	sortednp_, traffic_, ppages_, npages_, prequests_, nrequests_,
+	alphasortms_, alphasortfs_, alphasortns_, alphasortmp_,	alphasortfp_,
+	alphasortnp_, unsortedms_, unsortedfs_, unsortedns_, unsortedmp_,
+	unsortedfp_, unsortednp_, colon_, datefmt0_, datefmt1_,	datefmt2_};
 
 /*** Now include the user-definable header things ***/
 
@@ -320,7 +365,7 @@ struct stringlist {   /* a simple list of strings */
 /* in alias.c */
 extern flag doaliaslist(char *name, struct alias *listhead);
 #ifndef NODNS
-flag dnsresolve(char *hostn);
+extern flag dnsresolve(char *hostn);
 #endif
 extern int doaliashost(char *hostn);
 extern char *reversehostname(char *hostn);
@@ -328,8 +373,8 @@ extern int doaliasfile(char *filename);
 extern int doaliasref(char *name);
 extern int doalias(char *name, char codeletter);
 extern void allaliases(struct genstruct **objhead,
-  struct genstruct **objhead2, int hashsize, int *totalobjs, int *totalobjs7,
-  int *totalnew7, char code);
+  struct genstruct **objhead2, size_t hashsize, int *totalobjs,
+  int *totalobjs7, int *totalnew7, char code);
 extern int hosttodomcode(char *hostn);
 extern void urltodir(char *filename);
 extern char *urltoext(char *filename);
@@ -343,7 +388,7 @@ extern void repchoice(FILE *outf, char name[MAXSTRINGLENGTH], char codeletter,
   flag qq);
 extern void formgen(void);
 /* in hash.c */
-extern struct genstruct *hashadd(struct genstruct **objhead, int hashsize,
+extern struct genstruct *hashadd(struct genstruct **objhead, size_t hashsize,
   char *name, int reqs, double bytes, int pages, flag last7q, int *totalobjs,
   int *totalobjs7, int *totalnew7, flag al, flag maskq, flag ispage,
   struct genstruct *freespace, int magicnumber, char codeletter);
@@ -371,7 +416,7 @@ extern void datehash(int year, int monthno, int date, int hr, int min,
 extern void errsort(int errorder[NO_ERRS]);
 extern double bytefloor(double bytes, char *str);
 extern int reqfloor(int reqs, char *str);
-extern struct genstruct *gensort(struct genstruct **objhead, int hashsize,
+extern struct genstruct *gensort(struct genstruct **objhead, size_t hashsize,
   int tot_reqs, int tot_pages, double tot_bytes, int sortby, char *minreqstr,
   char *minpagestr, char *minbytestr, struct include *includehead,
   flag alphahost, int *maxreqs, int *maxpages, double *maxbytes,
@@ -386,6 +431,7 @@ extern void configline(char inputline[MAXLINELENGTH]);
 extern flag config(char *filename);
 extern void commandline(int argc, char **argv);
 extern void initialise(int argc, char **argv);
+extern void pvfiletest(char *name);
 extern void pvfilelist(struct stringlist *head,
   char filetype[MAXSTRINGLENGTH]);
 extern void printvbles(void);
@@ -439,7 +485,7 @@ extern void pvtime(char name[15], flag q, char graph, int unit, char cols[],
   int rows);
 extern void pvgen(char name[17], flag q, int sortby, char *minreqstr,
   char *minpagestr, char *minbytestr, char cols[], char singular[20],
-  char plural[21]);
+  char plural[21], char gender);
 extern void pvinout(char name[14], struct include *head);
 extern void pvalias(char name[8], struct alias *head);
 /* in macstuff.c */
@@ -450,8 +496,8 @@ extern void MacIdle(void);
 #endif
 #ifdef MAC
 #ifndef NODNS
-int IpAddr2Name(char *hostname);
-void ResolverCleanup(void);
+extern int IpAddr2Name(char *hostname);
+extern void ResolverCleanup(void);
 #endif
 #endif
 /* in output.c */
@@ -463,14 +509,19 @@ extern void output(struct genstruct *rsorthead, struct genstruct *isorthead,
 extern void gotos(FILE *outf, char c);
 extern void htmlputc(char c, FILE *outf);
 extern void htmlfprintf(FILE *outf, char string[MAXSTRINGLENGTH]);
+extern size_t htmlstrlen(char *s);
+extern void matchlength(FILE *outf, char *s, char c);
+extern size_t datefmtlen(char *fmt);
+extern void dateprintf(FILE *outf, char *fmt, int date, int month, int year,
+  int hr, int min);
 extern double finddivider(double bytes, char *bprefix);
 extern void asciiline(FILE *outf);
 extern void barplot(FILE *outf, int n);
 extern void precols(FILE *outf, char *wantcols, char codeletter, flag byq,
   flag pageq);
 extern void printcolheads(FILE *outf, char *wantcols, int fieldwidth,
-  int pfieldwidth, int bfieldwidth, char bprefix[2], char name[20], char type,
-  flag byq, flag pageq, flag name1st);
+  int pfieldwidth, int bfieldwidth, char bprefix[2], char name[20], int width,
+  char type, flag byq, flag pageq, flag name1st);
 extern void printcols(FILE *outf, char *wantcols, int reqs, int pages,
   double bytes, int fieldwidth, int pfieldwidth, int bfieldwidth,
   double bdivider, int totreqs, int totpages, double totbytes, char type,
@@ -490,7 +541,7 @@ extern void genout(FILE *outf, struct genstruct *sorthead, int tot_reqs,
 extern void domout(FILE *outf, int firstdom);
 extern void datehead(FILE *outf, int maxreq, int maxpages, double maxbytes,
   char *wantcols, char *graphtype, char anchor[11], char title[21],
-  char htmltitle[31], char colhead[13], char codeletter, int *unit,
+  char colhead[13], int colwidth, char codeletter, int *unit,
   int *fieldwidth, int *pfieldwidth, int *bfieldwidth, int *graphwidth,
   double *bdivider);
 extern void dateline(FILE *outf, int reqs, int pages, double bytes,
@@ -527,14 +578,14 @@ extern int sscanf_webstar(char *inputline, char hostn[MAXSTRINGLENGTH],
 typedef enum { NP_HTTP, NP_GOPHER, NP_ADMIN, NP_FTP, NP_GETFILE, NP_GETDIR,
 		 NP_LOGIN, NP_LOGOUT, NP_CGI, NP_ERROR } NP_type;
 typedef struct { char *str; NP_type value; } MatchPairs;
-NP_type checkValue(char *typeStr, const MatchPairs table[]);
-NP_type checkType(char *typeStr);
-void build_agent(char agent[MAXSTRINGLENGTH], NP_type entryType,
+extern NP_type checkValue(char *typeStr, const MatchPairs table[]);
+extern NP_type checkType(char *typeStr);
+extern void build_agent(char agent[MAXSTRINGLENGTH], NP_type entryType,
   char *entryTypeStr, NP_type actionType, char *actionTypeStr);
-int readDigits(char **from);
-int scan_path(char *inputline, char filename[MAXSTRINGLENGTH], int maxlen,
-  struct include *expandhead);
-int sscanf_netpresenz(FILE *logfile, char *inputline,
+extern int readDigits(char **from);
+extern int scan_path(char *inputline, char filename[MAXSTRINGLENGTH],
+  int maxlen, struct include *expandhead);
+extern int sscanf_netpresenz(FILE *logfile, char *inputline,
   char hostn[MAXSTRINGLENGTH], int *date, int *monthno, int *year, int *hr,
   int *min, char filename[MAXSTRINGLENGTH], char referer[MAXSTRINGLENGTH],
   char agent[MAXSTRINGLENGTH], int *code, char bytestr[16], size_t preflength);
@@ -548,8 +599,8 @@ extern int minsbetween(int date1, int monthno1, int year1, int hr1, int min1,
   int date2, int monthno2, int year2, int hr2, int min2);
 extern long timecode(int date, int monthno, int year, int hr, int min);
 extern struct timestruct startofweek(struct timestruct atime);
-extern FILE *fopenlog(char *name, char logtype[12], flag *ispipe);
-extern int fcloselog(FILE *f, char *name, char logtype[12], flag ispipe);
+extern FILE *fopenlog(char *name, char logtype[14], flag *ispipe);
+extern int fcloselog(FILE *f, char *name, char logtype[14], flag ispipe);
 extern void int3printf(FILE *outf, int x, char sepchar, int fieldwidth);
 extern void double3printf(FILE *outf, double x, char sepchar, int fieldwidth);
 extern void doublefprintf(FILE *outf, double x);
