@@ -1,4 +1,4 @@
-/*** analhead.h: header file for analog 2.0 ***/
+/*** analhead.h: header file for analog 2.1 ***/
 /* Please read Readme.html, or http://www.statslab.cam.ac.uk/~sret1/analog/  */
 
 /*** Change any of these according to your desires ***/
@@ -7,7 +7,8 @@
 #define ANALHEAD
 
 /*** The first few options -- up to LOGOURL -- are ones that you may want to
-     change before compiling the program for the first time. ***/
+     change before compiling the program for the first time. However, all of
+     them except MANDATORYCONFIGFILE can be changed at run time as well. ***/
 
 #define HOSTNAME "the Statistical Laboratory"
 /* the name of your organisation or WWW host. This is used for printing
@@ -17,20 +18,31 @@
 /* the URL of your host's home page, for linking to at the top of the
    output; use "-" for no linking. */
 
-#define DOMAINSFILE "/usr/local/etc/httpd/analog/domains.tab"
+#define HTTPDIR "/usr/local/etc/httpd/"
+#define ANALOGDIR HTTPDIR "analog/"
+/* The directories where your HTTP stuff lives and where your analog stuff
+   lives. You don't really need these; they are just used in this file to
+   build up other filenames. Note how you can stick together names by
+   just putting them next to each other; e.g., ANALOGDIR is defined as
+   HTTPDIR "analog/", which becomes "/usr/local/etc/httpd/analog/" */
+
+#define DOMAINSFILE ANALOGDIR "domains.tab"
 /* the name of the file where the domain definitions live; see README.html
    for the format of this file */
 
-#define LOGFILE "/usr/local/etc/httpd/logs/access_log"
+#define LOGFILE HTTPDIR "logs/access_log"
 /* The name of the default logfile; use "stdin" for stdin.
    Can be a list, separated by commas (but no spaces). */
 
 #define IMAGEDIR "/images/"
 /* URL of the directory where the images for the graphical reports live.
    The URL can be absolute, or relative to the output page: e.g., just the
-   empty string "" for the same directory as the output page. */
+   empty string "" for the same directory as the output page. Ends with /. */
 
-#define DEFAULTCONFIGFILE "/usr/local/etc/httpd/analog/analog.cfg"
+#define LANGDIR ANALOGDIR "lang/"
+/* Directory where the language files live. */
+
+#define DEFAULTCONFIGFILE ANALOGDIR "analog.cfg"
 /* the name of the default configuration file; see README.html for a
    description of this file. Use "none" for no configuration file. */
 
@@ -39,7 +51,7 @@
    overrides everything. Program exits if it is not found. Use "none"
    for none. */
 
-#define LOGOURL "/images/analogo.gif"
+#define LOGOURL IMAGEDIR "analogo.gif"
 /* the URL of the file where the analog logo lives. (One should have come
    with the program). You can put another logo in here (your organisation's
    logo, for example). Use "none" for no logo */
@@ -81,20 +93,20 @@
 #define CACHEFILE "none"
 /* The default file of cached time info. Use "none" for none. */
 
-#define REFERRER_LOG "/usr/local/etc/httpd/logs/referer_log"
+#define REFERRER_LOG HTTPDIR "logs/referer_log"
 /* The name of the default referrer log (= referer_log). Use "none" for none.
    Can be a list, separated by commas. */
 
-#define BROWSER_LOG "/usr/local/etc/httpd/logs/agent_log"
+#define BROWSER_LOG HTTPDIR "logs/agent_log"
 /* The name of the default browser log (= agent_log) similarly. */
 
-#define ERROR_LOG "/usr/local/etc/httpd/logs/error_log"
+#define ERROR_LOG HTTPDIR "logs/error_log"
 /* The name of the default error_log similarly. */
 
 #define NUMLOOKUP (OFF)
 /* whether to try and resolve IP addresses. Can be slow. */
 
-#define DNSFILE "/usr/local/etc/httpd/analog/dnscache"
+#define DNSFILE ANALOGDIR "dnscache"
 /* where to store resolved addresses so we don't have to look them up next
    time */
 
@@ -183,6 +195,9 @@
 #define BROWSER (OFF)     /* Browser summary */
 #define FULLBROWSER (OFF) /* Browser report */
 #define STATUS (OFF)      /* Status code report */
+#ifdef ERROR
+#undef ERROR
+#endif
 #define ERROR (OFF)       /* Error report */
 
 #define DOMCOLS "Rb"
