@@ -1,4 +1,4 @@
-/*** analog 2.0 ***/
+/*** analog 2.1 ***/
 /* Please read Readme.html, or http://www.statslab.cam.ac.uk/~sret1/analog/  */
 
 /*** analog.c; the main function ***/
@@ -110,6 +110,9 @@ int main(int argc, char **argv)
 
 #ifdef MAC_EVENTS
   MacInit();
+#endif
+#ifdef WIN32
+  Win32Init();
 #endif
   initialise(argc, argv);
   linesread = 0;
@@ -1039,6 +1042,9 @@ int main(int argc, char **argv)
 #ifdef MAC_EVENTS
   MacFini();
 #endif
+#ifdef WIN32
+  Win32Cleanup();
+#endif
 
   return(OK);
    
