@@ -1,4 +1,4 @@
-/*** analog 2.0 ***/
+/*** analog 2.1 ***/
 /* Please read Readme.html, or http://www.statslab.cam.ac.uk/~sret1/analog/  */
 
 /*** formgen.c; generate a form for the analog form interface ***/
@@ -226,7 +226,7 @@ void formgen(void)
   fprintf(outf, "<input type=reset value=\"Reset form\">\n");
   fprintf(outf, "</form>\n");
   fprintf(outf, "<P> <A HREF=\"http://www.webtechs.com/html-val-svc/\">\n");
-  fprintf(outf, "<IMG SRC=\"http://www.webtechs.com/html-val-svc/images/valid_html.gif\" ALT=\"HTML 2.0 Compliant!\"></A>\n");
+  fprintf(outf, "<IMG SRC=\"http://www.webtechs.com/html-val-svc/images/valid_html.gif\" ALT=\"HTML 2.0 Conformant!\"></A>\n");
   fprintf(outf, "</body></html>\n");
 
 }
