@@ -1,4 +1,4 @@
-/*** analog 2.0 ***/
+/*** analog 2.1 ***/
 /* Please read Readme.html, or http://www.statslab.cam.ac.uk/~sret1/analog/  */
 
 #include "analhea2.h"
@@ -10,7 +10,7 @@
   creating a new hash entry if none existed before. ***/
 
 /* Add a genstruct to the hash table. Return a pointer to the object. */
-struct genstruct *hashadd(struct genstruct **objhead, int hashsize,
+struct genstruct *hashadd(struct genstruct **objhead, size_t hashsize,
 			  char *name, int reqs, double bytes, int pages,
 			  flag last7q, int *totalobjs, int *totalobjs7,
 			  int *totalnew7, flag al, flag maskq, flag ispage,
@@ -1201,7 +1201,7 @@ int reqfloor(int reqs, char *str)
 }
 
 /* a function to sort the generic reports */
-struct genstruct *gensort(struct genstruct **objhead, int hashsize,
+struct genstruct *gensort(struct genstruct **objhead, size_t hashsize,
 			  int tot_reqs, int tot_pages, double tot_bytes,
 			  int sortby, char *minreqstr, char *minpagestr,
 			  char *minbytestr, struct include *includehead,
