@@ -1,4 +1,4 @@
-/*** analog 2.0 ***/
+/*** analog 2.1 ***/
 /* Please read Readme.html, or http://www.statslab.cam.ac.uk/~sret1/analog/  */
 
 /*** init2.c; some initialisation functions not using many global variables */
@@ -146,6 +146,7 @@ void dnscachescan(void)
 	if (warnq) {  /* NB: Poss. problem if strings too long */
 	  fprintf(stderr, "%s: Warning: Ignoring corrupt line in DNS cache file looking like\n", 
 		  commandname);
+	  fprintf(stderr,"  %s", inputline);
 	  anywarns = ON;
 	}
       }
@@ -948,11 +949,27 @@ void include_to_lower(struct include *head)
 
 /*** And finally some functions in connection with printvbles() ***/
 
-void pvfilelist(struct stringlist *head, char filetype[MAXSTRINGLENGTH])
+void pvfiletest(char *name)
 {
   extern flag stdin_used;
 
   FILE *filep;
+
+  if ((filep = fopen(name, "r")) == NULL && !STREQ(name, "stdin") &&
+      !STREQ(name, "-"))
+    printf("\n    Warning: cannot open that file");
+  else
+    fclose(filep);  /* NB So condl 3 lines back must be in that order */
+  if (STREQ(name, "stdin") || STREQ(name, "-")) {
+    if (stdin_used)
+      printf("\n    Warning: attempt to use stdin twice will fail");
+    stdin_used = TRUE;
+  }
+  printf("\n");
+}
+
+void pvfilelist(struct stringlist *head, char filetype[MAXSTRINGLENGTH])
+{
   struct stringlist *p;
 
   printf("%s to analyse:\n", filetype);
@@ -960,17 +977,7 @@ void pvfilelist(struct stringlist *head, char filetype[MAXSTRINGLENGTH])
     printf("  none\n");
   for (p = head; p -> name[0] != '\0'; p = p -> next) {  /* for each file */
     printf("  %s", p -> name);
-    if ((filep = fopen(p -> name, "r")) == NULL && !STREQ(p -> name, "stdin")
-	&& !STREQ(p -> name, "-"))
-      printf(":   Warning: cannot open that file");
-    else
-      fclose(filep);  /* NB So condl 3 lines back must be in that order */
-    if (STREQ(p -> name, "stdin") || STREQ(p -> name, "-")) {
-      if (stdin_used)
-	printf("\n  Warning: attempt to use stdin twice will fail");
-      stdin_used = TRUE;
-    }
-    printf("\n");
+    pvfiletest(p -> name);
   }
 }
 
@@ -1042,7 +1049,7 @@ void pvtime(char name[15], flag q, char graph, int unit, char cols[], int rows)
 
 void pvgen(char name[17], flag q, int sortby, char *minreqstr,
 	   char *minpagestr, char *minbytestr, char cols[], char singular[20],
-	   char plural[21])
+	   char plural[21], char gender)
 {
   int i;
 
@@ -1053,7 +1060,7 @@ void pvgen(char name[17], flag q, int sortby, char *minreqstr,
   if (q) {
     printf("  ");
     whatincluded(stdout, sortby, minreqstr, minpagestr, minbytestr, singular,
-		 plural, OFF, 'm');
+		 plural, OFF, gender);
     pvcols(cols);
   }
 }
