@@ -1,4 +1,4 @@
-/*** analog 2.0 ***/
+/*** analog 2.1 ***/
 /* Please read Readme.html, or http://www.statslab.cam.ac.uk/~sret1/analog/  */
 
 /*** sscanf.c; functions to replace sscanf(), which is far too slow, in
@@ -838,9 +838,9 @@ int sscanf_webstar(char *inputline, char hostn[MAXSTRINGLENGTH], int *date,
     if (*cin) ++cin;
     field_cnt=0;
     while (*cin && field_cnt<FIELDS_MAX) {
-      for (i=1; i<LAST_FIELD && memcmp((void *)cin,(void *)fnames[i],
-				       strlen(fnames[i]));
-	   ++i) ;
+      for (i=1; i<LAST_FIELD && (memcmp((void *)cin,(void *)fnames[i],
+           strlen(fnames[i])) || (cin[strlen(fnames[i])]!=' ' &&
+           cin[strlen(fnames[i])]!='\n')); ++i) ;
       if (i>=LAST_FIELD) i=INVALID;
       fields[field_cnt]=i;
       ++field_cnt;
@@ -1221,6 +1221,7 @@ int sscanf_netpresenz(FILE *logfile, char *inputline,
     else dateOrder=0;
   }
 #endif
+ do_again:
   /* read time */
   /* hour */
   if((*hr = readDigits(&cin)) < 0) return 0;
@@ -1319,17 +1320,10 @@ int sscanf_netpresenz(FILE *logfile, char *inputline,
      a bad line error, let's read a new line and start again. This stops
      lines which are not really bad from being counted as such.
      */
-  if(entryType == NP_ADMIN)
-    { int c;
-
-      if((c = fgetc(logfile)) == EOF) return(0);
-                   /* not much we can do in this case */
-      ungetc(c, logfile);  /* you never know it might be a one char line... */
-      fgets(inputline, MAXLINELENGTH, logfile);   /* won't fail -- >= 1 char */
-      return sscanf_netpresenz(logfile, inputline, hostn, date, monthno, year,
-			       hr, min, filename, referer, agent, code,
-			       bytestr, preflength);
-    }
+  if (entryType == NP_ADMIN) {
+    if (!fgets(inputline, MAXLINELENGTH, logfile)) return(0);
+        goto do_again;
+  }
   /* we have no use for the session, skip it */
   while(isdigit(*cin)) cin++;
   if(*cin++ != '\t')
@@ -1347,15 +1341,9 @@ int sscanf_netpresenz(FILE *logfile, char *inputline,
   actionType = checkValue(actionTypeStr, actionTypes);
 
   /* similar to above, ignore log in/out */
-  if(actionType == NP_LOGIN || actionType == NP_LOGOUT)
-    { int c;
-
-      if((c = fgetc(logfile)) == EOF) return(0);
-      ungetc(c, logfile);
-      fgets(inputline, MAXLINELENGTH, logfile);
-      return sscanf_netpresenz(logfile, inputline, hostn, date, monthno, year,
-			       hr, min, filename, referer, agent, code,
-			       bytestr, preflength);
+  if (actionType == NP_LOGIN || actionType == NP_LOGOUT) {
+      if (!fgets(inputline, MAXLINELENGTH, logfile)) return(0);
+          goto do_again;
     }
 
   /* now the file - this is the short version which we might discard in
