@@ -1,4 +1,4 @@
-/*** analog 2.0 ***/
+/*** analog 2.1 ***/
 /* Please read Readme.html, or http://www.statslab.cam.ac.uk/~sret1/analog/  */
 
 /*** utils.c; lots of little functions to do odd little things ***/
@@ -211,7 +211,7 @@ struct timestruct startofweek(struct timestruct atime)
 
 }
 
-FILE *fopenlog(char *name, char logtype[12], flag *ispipe)
+FILE *fopenlog(char *name, char logtype[14], flag *ispipe)
 {             /* open a logfile with a particular name for reading */
 #ifndef NOPIPES
   extern FILE *popen();
@@ -287,9 +287,11 @@ FILE *fopenlog(char *name, char logtype[12], flag *ispipe)
   return(f);
 }
 
-int fcloselog(FILE *f, char *name, char logtype[12], flag ispipe)
+int fcloselog(FILE *f, char *name, char logtype[14], flag ispipe)
 {     /* close it again */  /* logtype only used if NOPIPES off */
+#ifndef NOPIPES
   extern int pclose();
+#endif
 
   extern int debug;
 
@@ -437,8 +439,13 @@ void *xmalloc(size_t size)
 
   if ((answer = malloc(size)) == NULL) {
     fprintf(stderr, "%s: Ran out of memory: cannot continue\n", commandname);
-    if (sq == ON)
-      fprintf(stderr, "  Try turning hostname counting off or using approximate host counting");
+    if (sq == ON) {
+#ifdef MAC
+      fprintf(stderr, "  Try allocating more memory or using approximate host counting.\n");
+#else
+      fprintf(stderr, "  Try turning hostname counting off or using approximate host counting.\n");
+#endif
+    }
     exit(ERR);
   }
 
@@ -455,8 +462,13 @@ void *xcalloc(size_t nelem, size_t elsize)
 
   if ((answer = calloc(nelem, elsize)) == NULL) {
     fprintf(stderr, "%s: Ran out of memory: cannot continue\n", commandname);
-    if (sq == ON)
-      fprintf(stderr, "  Try turning hostname counting off or using approximate host counting");
+    if (sq == ON) {
+#ifdef MAC
+      fprintf(stderr, "  Try allocating more memory or using approximate host counting.\n");
+#else
+      fprintf(stderr, "  Try turning hostname counting off or using approximate host counting.\n");
+#endif
+    }
     exit(ERR);
   }
 
